@@ -1,14 +1,8 @@
-# We're doing this instead of a gem dependency so folks using Puppet
-# from their distro packages don't have to install the gem.
-begin
-  require 'puppet'
-rescue LoadError
-  puts 'Unable to require puppet.  Please gem install puppet and try again.'
-  exit 1
-end
-
+require 'puppet-lint/version'
+require 'puppet-lint/lexer'
 require 'puppet-lint/configuration'
 require 'puppet-lint/plugin'
+require 'puppet-lint/bin'
 
 unless String.respond_to?('prepend')
   class String
@@ -45,7 +39,7 @@ rescue
       if a.empty?
         string
       else
-        Percent.bind(string).call(*a, &b)
+        Percent.bind(string).call(a, &b)
       end
 
     end
@@ -74,9 +68,7 @@ end
 class PuppetLint::NoCodeError < StandardError; end
 
 class PuppetLint
-  VERSION = '0.1.12'
-
-  attr_reader :code, :file
+  attr_reader :data
 
   def initialize
     @data = nil
@@ -122,7 +114,17 @@ class PuppetLint
     puts format % message
   end
 
-  def report(problems)
+  def print_context(message, linter)
+    # XXX: I don't really like the way this has been implemented (passing the
+    # linter object down through layers of functions.  Refactor me!
+    return if message[:check] == 'documentation'
+    line = linter.manifest_lines[message[:linenumber] - 1]
+    offset = line.index(/\S/)
+    puts "\n  #{line.strip}"
+    printf "%#{message[:column] + 2 - offset}s\n\n", '^'
+  end
+
+  def report(problems, linter)
     problems.each do |message|
       @statistics[message[:kind]] += 1
       ## Add some default attributes.
@@ -131,10 +133,11 @@ class PuppetLint
 
       if configuration.error_level == message[:kind] or configuration.error_level == :all
         format_message message
+        print_context(message, linter) if configuration.with_context
       end
     end
   end
-  
+
   def errors?
     @statistics[:error] != 0
   end
@@ -143,27 +146,18 @@ class PuppetLint
     @statistics[:warning] != 0
   end
 
-  def checks
-    PuppetLint::CheckPlugin.repository.map do |plugin|
-      plugin.new.checks
-    end.flatten
-  end
-
   def run
     if @data.nil?
       raise PuppetLint::NoCodeError
     end
 
-    PuppetLint::CheckPlugin.repository.each do |plugin|
-      report plugin.new.run(@fileinfo, @data)
-    end
+    linter = PuppetLint::Checks.new
+    problems = linter.run(@fileinfo, @data)
+    report problems, linter
   end
 end
 
 # Default configuration options
-PuppetLint.configuration.fail_on_warnings = false
-PuppetLint.configuration.error_level = :all
-PuppetLint.configuration.with_filename = false
-PuppetLint.configuration.log_format = ''
+PuppetLint.configuration.defaults
 
 require 'puppet-lint/plugins'
